@@ -96,13 +96,14 @@ def _unqualify_unnest(expression: exp.Expression) -> exp.Expression:
 
     These are added by the optimizer's qualify_column step.
     """
+    from sqlglot.optimizer.scope import Scope
+
     if isinstance(expression, exp.Select):
         for unnest in expression.find_all(exp.Unnest):
             if isinstance(unnest.parent, (exp.From, exp.Join)) and unnest.alias:
-                for select in expression.selects:
-                    for column in select.find_all(exp.Column):
-                        if column.table == unnest.alias:
-                            column.set("table", None)
+                for column in Scope(expression).find_all(exp.Column):
+                    if column.table == unnest.alias:
+                        column.set("table", None)
 
     return expression
 
