@@ -63,11 +63,9 @@ class Context:
                 reader = table[i]
             yield reader, self
 
-    def table_iter(self, table: str) -> t.Iterator[t.Tuple[TableIter, Context]]:
+    def table_iter(self, table: str) -> TableIter:
         self.env["scope"] = self.row_readers
-
-        for reader in self.tables[table]:
-            yield reader, self
+        return iter(self.tables[table])
 
     def filter(self, condition) -> None:
         rows = [reader.row for reader, _ in self if self.eval(condition)]
