@@ -28,6 +28,8 @@ def simplify(expression):
     generate = cached_generator()
 
     def _simplify(expression, root=True):
+        if expression.meta.get("final"):
+            return expression
         node = expression
         node = rewrite_between(node)
         node = uniq_sort(node, generate, root)
@@ -398,6 +400,7 @@ def simplify_parens(expression):
         or not isinstance(this, exp.Binary)
         or (isinstance(this, exp.Add) and isinstance(parent, exp.Add))
         or (isinstance(this, exp.Mul) and isinstance(parent, exp.Mul))
+        or (isinstance(this, exp.Mul) and isinstance(parent, (exp.Add, exp.Sub)))
     ):
         return expression.this
     return expression
