@@ -1,6 +1,7 @@
 import unittest
 from concurrent.futures import ProcessPoolExecutor, as_completed
 from functools import partial
+from unittest.mock import patch
 
 import duckdb
 from pandas.testing import assert_frame_equal
@@ -14,6 +15,7 @@ from sqlglot.schema import MappingSchema
 from tests.helpers import (
     TPCDS_SCHEMA,
     TPCH_SCHEMA,
+    assert_logger_contains,
     load_sql_fixture_pairs,
     load_sql_fixtures,
     string_to_bool,
@@ -198,6 +200,15 @@ class TestOptimizer(unittest.TestCase):
         self.check_file("normalize", normalize)
 
     def test_qualify_columns(self):
+        self.assertEqual(
+            optimizer.qualify_columns.qualify_columns(
+                parse_one("WITH x AS (SELECT a FROM db.y) SELECT z FROM db.x"),
+                schema={"db": {"x": {"z": "int"}, "y": {"a": "int"}}},
+                infer_schema=False,
+            ).sql(),
+            "WITH x AS (SELECT y.a AS a FROM db.y) SELECT x.z AS z FROM db.x",
+        )
+
         self.assertEqual(
             optimizer.qualify_columns.qualify_columns(
                 parse_one("select y from x"),
@@ -207,6 +218,17 @@ class TestOptimizer(unittest.TestCase):
             "SELECT y AS y FROM x",
         )
 
+        self.assertEqual(
+            optimizer.qualify.qualify(
+                parse_one(
+                    "WITH X AS (SELECT Y.A FROM DB.Y CROSS JOIN a.b.INFORMATION_SCHEMA.COLUMNS) SELECT `A` FROM X",
+                    read="bigquery",
+                ),
+                dialect="bigquery",
+            ).sql(),
+            'WITH "x" AS (SELECT "y"."a" AS "a" FROM "DB"."Y" AS "y" CROSS JOIN "a"."b"."INFORMATION_SCHEMA"."COLUMNS" AS "columns") SELECT "x"."a" AS "a" FROM "x"',
+        )
+
         self.check_file("qualify_columns", qualify_columns, execute=True, schema=self.schema)
 
     def test_qualify_columns__with_invisible(self):
@@ -253,7 +275,7 @@ class TestOptimizer(unittest.TestCase):
         # check order of lateral expansion with no schema
         self.assertEqual(
             optimizer.optimize("SELECT a + 1 AS d, d + 1 AS e FROM x WHERE e > 1 GROUP BY e").sql(),
-            'SELECT "x"."a" + 1 AS "d", "x"."a" + 2 AS "e" FROM "x" AS "x" WHERE "x"."a" + 2 > 1 GROUP BY "x"."a" + 2',
+            'SELECT "x"."a" + 1 AS "d", "x"."a" + 1 + 1 AS "e" FROM "x" AS "x" WHERE "x"."a" + 2 > 1 GROUP BY "x"."a" + 1 + 1',
         )
 
         self.assertEqual(
@@ -391,6 +413,15 @@ FROM READ_CSV('tests/fixtures/optimizer/tpc-h/nation.csv.gz', 'delimiter', '|')
             {"s.b"},
         )
 
+    @patch("sqlglot.optimizer.scope.logger")
+    def test_scope_warning(self, logger):
+        self.assertEqual(len(traverse_scope(parse_one("WITH q AS (@y) SELECT * FROM q"))), 1)
+        assert_logger_contains(
+            "Cannot traverse scope %s with type '%s'",
+            logger,
+            level="warning",
+        )
+
     def test_literal_type_annotation(self):
         tests = {
             "SELECT 5": exp.DataType.Type.INT,
@@ -544,9 +575,10 @@ FROM READ_CSV('tests/fixtures/optimizer/tpc-h/nation.csv.gz', 'delimiter', '|')
 
     def test_function_annotation(self):
         schema = {"x": {"cola": "VARCHAR", "colb": "CHAR"}}
-        sql = "SELECT x.cola || TRIM(x.colb) AS col FROM x AS x"
+        sql = "SELECT x.cola || TRIM(x.colb) AS col, DATE(x.colb) FROM x AS x"
 
-        concat_expr_alias = annotate_types(parse_one(sql), schema=schema).expressions[0]
+        expression = annotate_types(parse_one(sql), schema=schema)
+        concat_expr_alias = expression.expressions[0]
         self.assertEqual(concat_expr_alias.type.this, exp.DataType.Type.VARCHAR)
 
         concat_expr = concat_expr_alias.this
@@ -555,6 +587,9 @@ FROM READ_CSV('tests/fixtures/optimizer/tpc-h/nation.csv.gz', 'delimiter', '|')
         self.assertEqual(concat_expr.right.type.this, exp.DataType.Type.VARCHAR)  # TRIM(x.colb)
         self.assertEqual(concat_expr.right.this.type.this, exp.DataType.Type.CHAR)  # x.colb
 
+        date_expr = expression.expressions[1]
+        self.assertEqual(date_expr.type.this, exp.DataType.Type.DATE)
+
         sql = "SELECT CASE WHEN 1=1 THEN x.cola ELSE x.colb END AS col FROM x AS x"
 
         case_expr_alias = annotate_types(parse_one(sql), schema=schema).expressions[0]
@@ -711,6 +746,23 @@ FROM READ_CSV('tests/fixtures/optimizer/tpc-h/nation.csv.gz', 'delimiter', '|')
         ).sql(pretty=True, dialect="snowflake")
 
         for func in (optimizer.qualify.qualify, optimizer.optimize):
-            source_query = parse_one('SELECT * FROM example."source"', read="snowflake")
+            source_query = parse_one('SELECT * FROM example."source" AS "source"', read="snowflake")
             transformed = func(source_query, dialect="snowflake", schema=schema)
             self.assertEqual(transformed.sql(pretty=True, dialect="snowflake"), expected)
+
+    def test_no_pseudocolumn_expansion(self):
+        schema = {
+            "a": {
+                "a": "text",
+                "b": "text",
+                "_PARTITIONDATE": "date",
+                "_PARTITIONTIME": "timestamp",
+            }
+        }
+
+        self.assertEqual(
+            optimizer.optimize(
+                parse_one("SELECT * FROM a"), schema=MappingSchema(schema, dialect="bigquery")
+            ),
+            parse_one('SELECT "a"."a" AS "a", "a"."b" AS "b" FROM "a" AS "a"'),
+        )
